@@ -1,7 +1,7 @@
 package Devel::EndStats;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2015-03-26'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use strict;
 use warnings;
@@ -174,7 +174,7 @@ END {
 
         $stats .= "\n";
         $stats .= "# Start stats from Devel::EndStats:\n";
-        $stats .= sprintf "# Program runtime duration: %.3fs\n", $secs;
+        $stats .= sprintf "# Program runtime duration: %.3fms\n", $secs*1000;
 
         my $files = 0;
         my $lines = 0;
@@ -285,7 +285,7 @@ Devel::EndStats - Display run time and dependencies after running code
 
 =head1 VERSION
 
-This document describes version 0.19 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2015-01-03.
+This document describes version 0.20 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2015-03-26.
 
 =head1 SYNOPSIS
 
@@ -414,7 +414,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Devel-EndS
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Devel-EndStats>.
+Source repository is at L<https://github.com/perlancar/perl-Devel-EndStats>.
 
 =head1 BUGS
 
